pub struct AccessLayer {
table_dir: String,
path_type: PathType,
object_store: ObjectStore,
puffin_manager_factory: PuffinManagerFactory,
intermediate_manager: IntermediateManager,
}Expand description
A layer to access SST files under the same directory.
Fields
table_dir: Stringpath_type: PathTypePath type for generating file paths.
object_store: ObjectStoreTarget object store.
puffin_manager_factory: PuffinManagerFactoryPuffin manager factory for index.
intermediate_manager: IntermediateManagerIntermediate manager for inverted index.
Implementations
Sourceimpl AccessLayer
impl AccessLayer
Sourcepub fn new(
table_dir: impl Into<String>,
path_type: PathType,
object_store: ObjectStore,
puffin_manager_factory: PuffinManagerFactory,
intermediate_manager: IntermediateManager,
) -> AccessLayer
pub fn new( table_dir: impl Into<String>, path_type: PathType, object_store: ObjectStore, puffin_manager_factory: PuffinManagerFactory, intermediate_manager: IntermediateManager, ) -> AccessLayer
Returns a new AccessLayer for specific table_dir.
Sourcepub fn object_store(&self) -> &ObjectStore
pub fn object_store(&self) -> &ObjectStore
Returns the object store of the layer.
Sourcepub fn puffin_manager_factory(&self) -> &PuffinManagerFactory
pub fn puffin_manager_factory(&self) -> &PuffinManagerFactory
Returns the puffin manager factory.
Sourcepub fn intermediate_manager(&self) -> &IntermediateManager
pub fn intermediate_manager(&self) -> &IntermediateManager
Returns the intermediate manager.
Sourcepub(crate) fn build_puffin_manager(
&self,
) -> FsPuffinManager<Arc<BoundedStager<RegionIndexId>>, ObjectStorePuffinFileAccessor>
pub(crate) fn build_puffin_manager( &self, ) -> FsPuffinManager<Arc<BoundedStager<RegionIndexId>>, ObjectStorePuffinFileAccessor>
Build the puffin manager.
pub(crate) async fn delete_index( &self, index_file_id: RegionIndexId, ) -> Result<(), Error>
pub(crate) async fn delete_ssts( &self, region_id: RegionId, file_ids: &[FileId], ) -> Result<(), Error>
pub(crate) async fn delete_indexes( &self, index_ids: &[RegionIndexId], ) -> Result<(), Error>
Sourcepub fn build_region_dir(&self, region_id: RegionId) -> String
pub fn build_region_dir(&self, region_id: RegionId) -> String
Returns the directory of the region in the table.
Sourcepub(crate) fn read_sst(&self, file: FileHandle) -> ParquetReaderBuilder
pub(crate) fn read_sst(&self, file: FileHandle) -> ParquetReaderBuilder
Returns a reader builder for specific file.
Sourcepub async fn write_sst(
&self,
request: SstWriteRequest,
write_opts: &WriteOptions,
metrics: &mut Metrics,
) -> Result<SstInfoArray>
pub async fn write_sst( &self, request: SstWriteRequest, write_opts: &WriteOptions, metrics: &mut Metrics, ) -> Result<SstInfoArray>
Writes a SST with specific file_id and metadata to the layer.
Returns the info of the SST. If no data written, returns None.
Sourcepub(crate) async fn put_sst(
&self,
data: &Bytes,
region_id: RegionId,
sst_info: &SstInfo,
cache_manager: &CacheManagerRef,
) -> Result<Metrics>
pub(crate) async fn put_sst( &self, data: &Bytes, region_id: RegionId, sst_info: &SstInfo, cache_manager: &CacheManagerRef, ) -> Result<Metrics>
Puts encoded SST bytes to the write cache (if enabled) and uploads it to the object store.
Sourcepub fn storage_sst_entries(
&self,
) -> impl Stream<Item = Result<StorageSstEntry>> + use<>
pub fn storage_sst_entries( &self, ) -> impl Stream<Item = Result<StorageSstEntry>> + use<>
Lists the SST entries from the storage layer in the table directory.